import PyCara.PyCaraExport as PyCaraExport
import argparse
import sys
import os



#########################################
# Demonstrate how to query a Cara file  
#

parser = argparse.ArgumentParser()
parser.add_argument('filename', help='filename', nargs='?' )
args = parser.parse_args()

filename = args.filename

if filename == None:
    print "Must supply a filename"
    sys.exit(1)


# Create an instance of the Cara processing engine
cara = PyCaraExport.CaraExport()

# Open a solved Cara project file
if not cara.open( filename ):
    print "failed to open cara file [{}]".format(filename)
    sys.exit(1)

# Obtain the frame rate of the capture and the timecode standard 
print "frame rate (Hz) [{}]".format(cara.frame_rate())
print "timecode standard [{}]".format(cara.timecode_standard())

# For the first 10 frames of the sequence, output the frame index, the timecode as a string, 
# and a tuple containing the timecode information 
for frame in xrange(10):
    print frame, cara.timecode_string(frame), cara.timecode(frame)

    
# For each face point in the project file, output the point's id and 
# the name of the point (assuming there is a user-defined name)
for i in cara.face_points():
    print "face : ", i, cara.point_name(i)

    
# For each brim in the project file, output the point's id and 
# the name of the point
for i in cara.brim_points():
    print "brim : ", i, cara.point_name(i)

    
# For a given sensor, pull out the 2d data for all tracked points
# in a range of frames 
# (both face and brim points) 
sensor_index = 0
image_size = cara.image_size( sensor_index )

pos = []

# PyCaraExport.points() will give all the point ids, both face and brim
points = cara.points()
frames = range(250,300)
for frame_index in frames:

    # PyCaraExport.detections() will pull out all the 2d points for a given 
    # (sensor_index,frame_index) pair. The data is returned in a dict 
    # which maps a local id (the point 2d index) to the point information
    detections = cara.detections( sensor_index, frame_index)
    
    # PyCaraExport.track_data() will generate a dictionary mapping
    # point id to the local point 2d indices which are used in the 
    # the dict produced by PyCaraExport.detections()
    track_data = cara.track_data( sensor_index, frame_index)
   
    for point_id in points:
        if track_data.has_key(point_id):
            if detections.has_key( track_data[point_id] ):
                d = detections[track_data[point_id]]
                pos.append( (d[0], d[1]) )

# If we have pylab installed then plot the points,
# Note that the points are flipped in the y-axis, as the coordinate system has
# (0,0) as the TOP-left corner of the image (whereas pylab uses the bottom-left corner)
try:
    import pylab
    pylab.plot( [0, 0, image_size[0], image_size[0], 0], [0, image_size[1], image_size[1], 0, 0], 'b-'  )
    pylab.plot( [x for (x,y) in pos], [image_size[1] - y for (x,y) in pos], 'ro'  )
    pylab.axis ( [0, image_size[0], 0, image_size[1] ] ) 
    pylab.axes().set_aspect( 'equal')
    pylab.show()
except ImportError:
    print "This example uses pylab to plot the data. Please install pylab."
