import sys
import os
import time
import argparse
import PyCara.PyDebugServices as PyDebugServices
PyDebugServices.set_global_log_level(0)
import PyCara.PyCaraProcess as PyCaraProcess
import glob
import os



    
def process_files( input, process_file, valid_endings = (".cara", ".pico"), verbose=False ):
    """this is a simple batch processing script that takes an input filename generator, and a 
    processing function and a list of valid file endings, and attempts to apply the processing
    function to all valid filenames
    """

    files = glob.glob( input )
    files_to_process = []

    if not files:
        print "The file specified did not generate any files or directories [{}]".format(input)
        sys.exit(1)

    
    action = None
    collect_filenames_then_process = False

    if collect_filenames_then_process:
        def action(filename): 
            files_to_process.append(filename)
    else:
        def action(filename): process_file(filename)
    
    for top in files:
        if valid_endings is None or top.endswith( valid_endings ):
            action( top )
        for dirpath, dirnames, filenames in os.walk(top):
            if verbose: print dirpath
            for file in filenames:
                if valid_endings is None or file.endswith( valid_endings ):
                    action( os.path.join( dirpath, file ) )
                    
    for filename in files_to_process:
        process_file( filename )


def import_detect_blobs_and_save(filename):
    """this function takes a pico filename, and attempts to import all pico files
    for that take, detect blobs and then save toa cara file
    """

    # strip off the last 7 characters from the filename
    if not filename.endswith('.pico'):
        return

    take_name = filename[0:-7] 
    print "-----"
    print "processing {}".format(take_name)

    save_name = '{}_b.cara'.format( take_name )

    if os.path.exists(save_name):
        print "  Cara file [{}] already exists".format( save_name )
        return
    
    # Create an instance of the Cara processing engine
    cara = PyCaraProcess.CaraProcess()

    # Import the pico files containing the video from the capture
    pico_files = ['{}_{}.pico'.format(take_name, i) for i in xrange(4) ]
    ok = cara.import_pico_files( pico_files )
    print "  import_pico_files {}".format(ok)

    if not ok:
        print " Failed to import pico_files"
        return

    # Blob detect
    start = time.time()
       
    ok = cara.detect_blobs()
    elapsed = time.time()-start
    print "  detect_blobs {}  time elapsed {:.1f}s".format(ok, elapsed)
    
    if not ok:
        print " Failed to detect blobs"
        return


    # Save the resulting file with detected blobs
    dir, take_name_no_path = os.path.split(take_name)
    cara.save( '{}_b.cara'.format( take_name ) )


##################################
# Batch Detect Blobs
#

# This example demonstrates how to use python and PyCara to find all the .pico files
# in a given directory and then import them into a new Cara project and perform
# blob detection 

parser = argparse.ArgumentParser()
parser.add_argument('input', help='file or directory specifier (wildcards allowed)', nargs='?' )
args = parser.parse_args()

if args.input == None:
    print "Must supply a file or directory specifier"
    sys.exit(1)



process_files( args.input, import_detect_blobs_and_save, valid_endings = ("_0.pico"), verbose=True )
