import sys
import os
import time
import argparse
import PyCara.PyDebugServices as PyDebugServices
PyDebugServices.set_global_log_level(0)
import PyCara.PyCaraProcess as PyCaraProcess

##################################
# Detect Blobs
#

# This example demonstrates how to load a take and blob detect 

parser = argparse.ArgumentParser()
parser.add_argument('filename', help='name of a .pico file', nargs=1 )
args = parser.parse_args()

filename = args.filename[0]

# strip off the last 7 characters from the filename
if not filename.endswith('.pico'):
    print "Please supply a pico file"
    sys.exit(1)

take_name = filename[0:-7] 

# Create an instance of the Cara processing engine
cara = PyCaraProcess.CaraProcess()


# Import the pico files containing the video from the capture
pico_files = ['{}_{}.pico'.format(take_name, i) for i in xrange(4) ]
ok = cara.import_pico_files( pico_files )
print "import_pico_files {}".format(ok)

if not ok:
    print "Failed to import pico file(s)"
    for i in xrange(4):
        print "  " + pico_files[i]
    sys.exit(1)


# Blob detect
# There are two main inputs to blob tracking
# 1) Detection Parameters
#  
# By default the detection parameters will be read from the .pico files
# as it is assumed that when the take was captured using CaraLive, the 
# blob detection parameters were correctly set.
#
# However, the user can override the parameters if necessary.
# The complete list of parameters and their defaults is :
#
#BlobParameters.FindBlackBlobs : True
#BlobParameters.FindWhiteBlobs : False
#BlobParameters.BlackMaxRadius : 50.0
#BlobParameters.BlackMinRadius : 4.0
#BlobParameters.BlackThreshold : 0.4
#BlobParameters.WhiteMaxRadius : 50.0
#BlobParameters.WhiteMinRadius : 4.0
#BlobParameters.WhiteThreshold : 0.4
# 
# In order to set the parameters the user can use :
#
#cara.set_property("BlobParameters.FindBlackBlobs", False)
#cara.set_property("BlobParameters.FindWhiteBlobs", True)
#cara.set_property("BlobParameters.WhiteThreshold", 0.4)
#
# 2) Detection Processing Range
#
# There are two version of the  detect_blobs member function
# The first takes no arguments and will detect blobs on all frames
# The second will take the arguments  
#    (list)list of sensors
#    (int)start frame index
#    (int)end frame index
# This allows more flexibility in detecting blobs over a subset of the 
# frames/cameras
# e.g. to track the first 100 frames of all cameras
# cara.detect_blobs( [0,1,2,3], 0, 99 )

start = time.time()
ok = cara.detect_blobs()

if not ok:
    print "Failed to detect blobs"
    sys.exit(1)

elapsed = time.time()-start
print "detect_blobs {}  time elapsed {:.1f}s".format(ok, elapsed) 

# Save the resulting file with detected blobs
dir, take_name_no_path = os.path.split(take_name)
cara.save( '{}_b.cara'.format( take_name_no_path ) )
