import sys
import os
import time
import PyCara.PyDebugServices as PyDebugServices
PyDebugServices.set_global_log_level(0)
import PyCara.PyCaraProcess as PyCaraProcess

# assumes that the Vicon sample data is in the current folder in sub-folder "Sample Data"
data_directory = '.\\Sample Data'

##################################
# Setup a Cara project
#


# This example demonstrates how to setup a Cara project from the raw pico files,
# and detect blobs in preparation for full initialization and tracking 

# Create an instance of the Cara processing engine
cara = PyCaraProcess.CaraProcess()


take_name = 'ROM'

# Import the pico files containing the video from the capture
pico_files = ['{}_{}.pico'.format(take_name, i) for i in xrange(4) ]
pico_files = [ os.path.join( data_directory, (filename) ) for filename in pico_files]
ok = cara.import_pico_files( pico_files )
print "import_pico_files {}".format(ok)

if not ok:
    print "Failed to import pico file(s)"
    for i in xrange(4):
        print "  " + pico_files[i]
    sys.exit(1)


# Import the calibration file corresponding to the capture
ok = cara.import_xcp( os.path.join( data_directory, 'Calibration.xcp' ) )
print "import_xcp {}".format(ok)

if not ok:
    print "Failed to import xcp file " + os.path.join( data_directory, 'Calibration.xcp' ) 
    sys.exit(1)

# Initialize the default calibration brim 
ok = cara.initialize_default_calibration_brim()
print "initialize_default_calibration_brim {}".format(ok)


# Blob detect
# first change any blob detection properties if necessary
cara.set_property("BlobParameters.FindBlackBlobs", False)
cara.set_property("BlobParameters.FindWhiteBlobs", True)
cara.set_property("BlobParameters.WhiteThreshold", 0.4)

# then detect the blobs
start = time.time()
ok = cara.detect_blobs()
elapsed = time.time()-start
print "detect_blobs {}  time elapsed {:.1f}s".format(ok, elapsed)

if not ok:
    print "Failed to detect blobs"
    sys.exit(1)


# Save the resulting file with detected blobs
ok = cara.save( 'ROM_b.cara' )

if not ok:
    print "Failed to save file ROM_b.cara" 
    sys.exit(1)



