import sys
import time
import os
import argparse
import PyCara.PyDebugServices as PyDebugServices
#PyDebugServices.set_global_log_level(0)
import PyCara.PyCaraProcess as PyCaraProcess

def succeeded( ok ):
    if ok:
        return "succeeded"
    return "failed"
    
data_directory = '.\data'
    
##################################
# Track a cara file, or setup and track using .pico files 
#

parser = argparse.ArgumentParser()
parser.add_argument('filename', help='name of a .pico or .cara file', nargs='?', default = os.path.join(data_directory,'Franchesca_Expressions_02-20130617-1649_0.pico') )
parser.add_argument('--rom', help='name of a .cara ROM file')
args = parser.parse_args()

# Create an instance of the Cara processing engine
cara = PyCaraProcess.CaraProcess()

take_name = None
take_dir = None

if args.filename.endswith('.cara'):
    cara.open( args.filename )
    take_dir, take_name = os.path.split(args.filename[0:-4])
elif args.filename.endswith('.pico'):
    take_dir, take_name = os.path.split(args.filename[0:-7])

    if args.rom is None:
        print "Please supply a ROM file to initialize the take"
        sys.exit(1)
    pico_files = ['{}_{}.pico'.format( os.path.join(take_dir,take_name), i) for i in xrange(4) ]
    ok = cara.import_pico_files( pico_files )
    print "import_pico_files {}".format(succeeded(ok))

    if not ok:
        print "Failed to import pico file(s)"
        for i in xrange(4):
            print "  " + pico_files[i]
        sys.exit(1)

    # Initialize from the ROM 
    ok = cara.initialize_from_ROM( args.rom, 0, 0, False)
    print "initialize_from_ROM {}".format(succeeded(ok))

    if not ok:
        print "Failed to initialize from ROM from ROM file: " + args.rom
        sys.exit(1)


    # Save the resulting file
    outputFile = '{}_i.cara'.format(take_name)
    ok = cara.save( outputFile )
    print "save {}".format(succeeded(ok))

    if not ok:
        print "Failed to save initialized file: " + outputFile
        sys.exit(1)
    else:
        print "Saved initialized file as: " + outputFile
else:
    print "Please supply a valid .cara or .pico file"
    sys.exit(1)
    
    
# Perform feature tracking 
#
# There are two main inputs to tracking
# 1) Tracking Parameters
#  
# The full list of properties affecting tracking is as follows :
#
# TrackingParameters.AllowSingleSensorTracking : True
# TrackingParameters.BlobSizeDifferenceThreshold : 0.75
# TrackingParameters.HeadBarTrackingDistance : 15.0
# TrackingParameters.OutlierRemovalThreshold2D : 5.0
# TrackingParameters.OutlierRemovalThreshold3D : 5.0
# TrackingParameters.PatchMatchSize : 15.0
# TrackingParameters.PatchMatchThreshold : 0.8
# TrackingParameters.RemoveOutliers2D : True
# TrackingParameters.RemoveOutliers3D : True
# TrackingParameters.SingleSensorTrackingThreshold : 0.5
# TrackingParameters.TPSPredictionDistance : 15.0
# TrackingParameters.TrackingDistance : 35.0
#
# Please consult the CaraPost reference documentation for an explanation of these
# parameters. 
#
# In order to set the parameters the user can use :
#
# cara.set_property("TrackingParameters.AllowSingleSensorTracking", False)
#
# 2) Tracking Range
# 
#  The full list of parameters for tracking is 
#   Start frame position - start frame as a zero-based index
#   Number of frames     - defaults to -1  which means "track all frames from start in the selected direction"
#   Track forwards       - boolean value, True for track forwards, False for track backwards 

start = time.time()
ok = cara.track( 1 )
elapsed = time.time()-start
print "track {}  time elapsed {:.1f}s".format(succeeded(ok), elapsed)


if not ok:
    sys.exit(1)


# Save the resulting file with detected blobs
outputFile= '{}_t.cara'.format(take_name)
ok = cara.save( outputFile )
print "save {}".format(succeeded(ok))
if not ok:
    print "Failed to save tracking results as file: " + outputFile
    sys.exit(1)
else:
    print "Saved tracking results as: " + outputFile

